"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const metadataInfo_1 = require("../metadataInfo");
const baseMetadataRetriever_1 = __importDefault(require("./baseMetadataRetriever"));
const metadataFiles_1 = __importDefault(require("../metadataFiles"));
const QUERY = "SELECT Id, DeveloperName, NamespacePrefix From ExternalDataSource";
class ExternalDataSourceRetriever extends baseMetadataRetriever_1.default {
    constructor(org) {
        super(org, false);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!ExternalDataSourceRetriever.instance) {
            ExternalDataSourceRetriever.instance = new ExternalDataSourceRetriever(org);
        }
        return ExternalDataSourceRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            super.setQuery(QUERY);
            let dataSources = await super.getObjects();
            for (let i = 0; i < dataSources.length; i++) {
                let dts = dataSources[i];
                if (!lodash_1.default.isNil(dts.NamespacePrefix)) {
                    dts.FullName = `${dts.NamespacePrefix}__${dts.DeveloperName}`;
                }
                else {
                    dts.FullName = dts.DeveloperName;
                }
            }
            this.data = dataSources;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getExternalDataSources() {
        return await this.getObjects();
    }
    async externalDataSourceExists(dataSource) {
        let found = false;
        //Look first in project files
        if (!lodash_1.default.isNil(metadataInfo_1.METADATA_INFO.ExternalDataSource.components)) {
            found = metadataInfo_1.METADATA_INFO.ExternalDataSource.components.includes(dataSource);
        }
        if (!found && !metadataFiles_1.default.sourceOnly) {
            //not found, check on the org
            let dataSources = await this.getExternalDataSources();
            let foundDts = dataSources.find(dts => {
                return dts.FullName === dataSource;
            });
            found = !lodash_1.default.isNil(foundDts);
        }
        return found;
    }
}
exports.default = ExternalDataSourceRetriever;
//# sourceMappingURL=externalDataSourceRetriever.js.map