"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const metadataInfo_1 = require("../metadataInfo");
const baseMetadataRetriever_1 = __importDefault(require("./baseMetadataRetriever"));
const metadataFiles_1 = __importDefault(require("../metadataFiles"));
const QUERY = "SELECT Id, MasterLabel, FullName  From Flow";
class FlowRetriever extends baseMetadataRetriever_1.default {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!FlowRetriever.instance) {
            FlowRetriever.instance = new FlowRetriever(org);
        }
        return FlowRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            let flows = await this.retrieveFlows();
            this.data = flows;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async retrieveFlows() {
        const apiversion = await this.org.retrieveMaxApiVersion();
        let toReturn = new Promise((resolve, reject) => {
            this.org
                .getConnection()
                .metadata.list([{ type: "Flow", folder: null }], apiversion, function (err, metadata) {
                if (err) {
                    return reject(err);
                }
                let flowsObjList = [];
                for (let i = 0; i < metadata.length; i++) {
                    let flow = {
                        FullName: metadata[i].fullName,
                        NamespacePrefix: metadata[i].namespacePrefix,
                        Id: ""
                    };
                    if (metadata[i].namespacePrefix !== "" &&
                        metadata[i].namespacePrefix !== undefined) {
                        flow.FullName = `${metadata[i].namespacePrefix}__${metadata[i].fullName}`;
                    }
                    flowsObjList.push(flow);
                }
                resolve(flowsObjList);
            });
        });
        return toReturn;
    }
    async getFlows() {
        return await this.getObjects();
    }
    async flowExists(flowStr) {
        let found = false;
        //Look first in project files
        if (!lodash_1.default.isNil(metadataInfo_1.METADATA_INFO.Flow.components)) {
            found = metadataInfo_1.METADATA_INFO.Flow.components.includes(flowStr);
        }
        if (!found && !metadataFiles_1.default.sourceOnly) {
            //not found, check on the org
            let flows = await this.getFlows();
            let foundFlow = flows.find(flow => {
                return flow.FullName === flowStr;
            });
            found = !lodash_1.default.isNil(foundFlow);
        }
        return found;
    }
}
exports.default = FlowRetriever;
//# sourceMappingURL=flowRetriever.js.map