"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const sfpowerkit_1 = require("../../../sfpowerkit");
const metadataFiles_1 = __importDefault(require("../../metadata/metadataFiles"));
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const metadataInfo_1 = require("../../metadata/metadataInfo");
const lodash_1 = __importDefault(require("lodash"));
const profileActions_1 = __importDefault(require("./profileActions"));
const profileWriter_1 = __importDefault(require("../../../impl/metadata/writer/profileWriter"));
const unsupportedprofiles = [];
class ProfileSync extends profileActions_1.default {
    async sync(srcFolders, profiles, isdelete) {
        sfpowerkit_1.SFPowerkit.log("Retrieving profiles", sfpowerkit_1.LoggerLevel.DEBUG);
        sfpowerkit_1.SFPowerkit.log("Requested  profiles are..", sfpowerkit_1.LoggerLevel.DEBUG);
        sfpowerkit_1.SFPowerkit.log(profiles, sfpowerkit_1.LoggerLevel.DEBUG);
        let fetchNewProfiles = lodash_1.default.isNil(srcFolders) || srcFolders.length === 0;
        if (fetchNewProfiles) {
            srcFolders = await sfpowerkit_1.SFPowerkit.getProjectDirectories();
        }
        this.metadataFiles = new metadataFiles_1.default();
        sfpowerkit_1.SFPowerkit.log("Source Folders are", sfpowerkit_1.LoggerLevel.DEBUG);
        sfpowerkit_1.SFPowerkit.log(srcFolders, sfpowerkit_1.LoggerLevel.DEBUG);
        for (let i = 0; i < srcFolders.length; i++) {
            let srcFolder = srcFolders[i];
            let normalizedPath = path.join(process.cwd(), srcFolder);
            this.metadataFiles.loadComponents(normalizedPath);
        }
        let profileList = [];
        let profileNames = [];
        let profilePathAssoc = {};
        let profileStatus = await this.getProfileFullNamesWithLocalStatus(profiles);
        sfpowerkit_1.SFPowerkit.log(profileStatus, sfpowerkit_1.LoggerLevel.DEBUG);
        let metadataFiles = profileStatus.updated || [];
        if (fetchNewProfiles) {
            metadataFiles = lodash_1.default.union(profileStatus.added, profileStatus.updated);
        }
        else {
            metadataFiles = profileStatus.added;
        }
        metadataFiles.sort();
        sfpowerkit_1.SFPowerkit.log(metadataFiles, sfpowerkit_1.LoggerLevel.TRACE);
        for (var i = 0; i < metadataFiles.length; i++) {
            var profileComponent = metadataFiles[i];
            var profileName = path.basename(profileComponent, metadataInfo_1.METADATA_INFO.Profile.sourceExtension);
            var supported = !unsupportedprofiles.includes(profileName);
            if (supported) {
                profilePathAssoc[profileName] = profileComponent;
                profileNames.push(profileName);
            }
        }
        var i, j, chunk = 10;
        var temparray;
        sfpowerkit_1.SFPowerkit.log("Number of profiles found in the target org " + profileNames.length, sfpowerkit_1.LoggerLevel.INFO);
        for (i = 0, j = profileNames.length; i < j; i += chunk) {
            temparray = profileNames.slice(i, i + chunk);
            //SfPowerKit.ux.log(temparray.length);
            let start = i + 1;
            let end = i + chunk;
            sfpowerkit_1.SFPowerkit.log("Loading profiles in batches " + start + " to " + end, sfpowerkit_1.LoggerLevel.INFO);
            var metadataList = await this.profileRetriever.loadProfiles(temparray, this.conn);
            let profileWriter = new profileWriter_1.default();
            for (var count = 0; count < metadataList.length; count++) {
                var profileObj = metadataList[count];
                profileWriter.writeProfile(profileObj, profilePathAssoc[profileObj.fullName]);
                //SfPowerKit.ux.log("Profile " + profileObj.fullName + " Sync!");
                profileList.push(profileObj.fullName);
            }
        }
        if (profileStatus.deleted && isdelete) {
            profileStatus.deleted.forEach(file => {
                if (fs.existsSync(file)) {
                    fs.unlinkSync(file);
                }
            });
        }
        return Promise.resolve(profileStatus);
    }
}
exports.default = ProfileSync;
//# sourceMappingURL=profileSync.js.map